==> qtjambi-qt3drender-6.6.0-sources.jar: io/qt/qt3d/render/QRenderSettings.java <==
package io.qt.qt3d.render;

import io.qt.*;


/**
 * <p>Holds settings related to rendering process and host the active FrameGraph</p>
 * <p>Java wrapper for Qt class <code><a href="https://doc.qt.io/qt/qt3drender-qrendersettings.html">Qt3DRender::QRenderSettings</a></code></p>
 */
public class QRenderSettings extends io.qt.qt3d.core.QComponent
{
    static {
        QtJambi_LibraryUtilities.initialize();
    }
    
    
    /**
     * This variable stores the meta-object for the class.
     */
    public static final io.qt.core.@NonNull QMetaObject staticMetaObject = io.qt.core.QMetaObject.forType(QRenderSettings.class);
    
    /**
     * <p>Java wrapper for Qt enum <code><a href="https://doc.qt.io/qt/qt3drender-qrendersettings.html#RenderPolicy-enum">Qt3DRender::QRenderSettings::RenderPolicy</a></code></p>
     */
    public enum RenderPolicy implements QtEnumerator {
        /**
         * <p>Representing <code><a href="https://doc.qt.io/qt/qt3drender-qrendersettings.html#RenderPolicy-enum">Qt3DRender::<wbr>QRenderSettings::<wbr>OnDemand</a></code></p>
         */
        OnDemand(0),
        /**
         * <p>Representing <code><a href="https://doc.qt.io/qt/qt3drender-qrendersettings.html#RenderPolicy-enum">Qt3DRender::<wbr>QRenderSettings::<wbr>Always</a></code></p>
         */
        Always(1);

        static {
            QtJambi_LibraryUtilities.initialize();
        }

        private RenderPolicy(int value) {
            this.value = value;
        }

        /**
         * {@inheritDoc}
         */
        public int value() {
            return value;
        }

        /**
         * Returns the corresponding enum entry for the given value.
         * @param value
         * @return enum entry
         */
        public static @NonNull RenderPolicy resolve(int value) {
            switch (value) {
            case 0: return OnDemand;
            case 1: return Always;
            default: throw new QNoSuchEnumValueException(value);
            }
        }


        private final int value;
    }
    

    /**
     * <p>See <code><a href="https://doc.qt.io/qt/qt3drender-qrendersettings.html#activeFrameGraph-prop">Qt3DRender::QRenderSettings::<wbr>activeFrameGraphChanged(Qt3DRender::QFrameGraphNode*)</a></code></p>
     */
    @QtPropertyNotify(name="activeFrameGraph")
    public final @NonNull Signal1<io.qt.qt3d.render.@Nullable QFrameGraphNode> activeFrameGraphChanged = new Signal1<>();

    /**
     * <p>See <code><a href="https://doc.qt.io/qt/qt3drender-qrendersettings.html#renderPolicy-prop">Qt3DRender::QRenderSettings::<wbr>renderPolicyChanged(Qt3DRender::QRenderSettings::RenderPolicy)</a></code></p>
     */
    @QtPropertyNotify(name="renderPolicy")
    public final @NonNull Signal1<io.qt.qt3d.render.QRenderSettings.@NonNull RenderPolicy> renderPolicyChanged = new Signal1<>();
    
    /**
     * <p>See <code>Qt3DRender::QRenderSettings::<wbr>QRenderSettings(Qt3DCore::QNode*)</code></p>
     */
    @SuppressWarnings({"exports"})
    public QRenderSettings(io.qt.qt3d.core.@Nullable QNode parent){
        super((QPrivateConstructor)null);
        initialize_native(this, parent);
    }
    
    private native static void initialize_native(QRenderSettings instance, io.qt.qt3d.core.QNode parent);
    
    /**
     * <p>See <code><a href="https://doc.qt.io/qt/qt3drender-qrendersettings.html#activeFrameGraph-prop">Qt3DRender::QRenderSettings::<wbr>activeFrameGraph()const</a></code></p>
     */
    @QtPropertyReader(name="activeFrameGraph")
    @QtUninvokable
    public final io.qt.qt3d.render.@Nullable QFrameGraphNode activeFrameGraph(){
        return activeFrameGraph_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native io.qt.qt3d.render.QFrameGraphNode activeFrameGraph_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <code><a href="https://doc.qt.io/qt/qt3drender-qrendersettings.html#pickingSettings-prop">Qt3DRender::QRenderSettings::<wbr>pickingSettings()</a></code></p>
     */
    @QtPropertyReader(name="pickingSettings")
    @QtPropertyConstant
    @QtUninvokable
    public final io.qt.qt3d.render.@Nullable QPickingSettings pickingSettings(){
        return pickingSettings_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native io.qt.qt3d.render.QPickingSettings pickingSettings_native(long __this__nativeId);
    
    /**
     * <p>See <code><a href="https://doc.qt.io/qt/qt3drender-qrendersettings.html#renderCapabilities-prop">Qt3DRender::QRenderSettings::<wbr>renderCapabilities()</a></code></p>
     */
    @QtPropertyReader(name="renderCapabilities")
    @QtPropertyConstant
    @QtUninvokable
    public final io.qt.qt3d.render.@Nullable QRenderCapabilities renderCapabilities(){
        return renderCapabilities_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native io.qt.qt3d.render.QRenderCapabilities renderCapabilities_native(long __this__nativeId);
    
    /**
     * <p>See <code><a href="https://doc.qt.io/qt/qt3drender-qrendersettings.html#renderPolicy-prop">Qt3DRender::QRenderSettings::<wbr>renderPolicy()const</a></code></p>
     */
    @QtPropertyReader(name="renderPolicy")
    @QtUninvokable
    public final io.qt.qt3d.render.QRenderSettings.@NonNull RenderPolicy renderPolicy(){
        return io.qt.qt3d.render.QRenderSettings.RenderPolicy.resolve(renderPolicy_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this)));
    }
    
    @QtUninvokable
    private native int renderPolicy_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <code><a href="https://doc.qt.io/qt/qt3drender-qrendersettings.html#activeFrameGraph-prop">Qt3DRender::QRenderSettings::<wbr>setActiveFrameGraph(Qt3DRender::QFrameGraphNode*)</a></code></p>
     */
    @QtPropertyWriter(name="activeFrameGraph")
    public final void setActiveFrameGraph(io.qt.qt3d.render.@Nullable QFrameGraphNode activeFrameGraph){
        setActiveFrameGraph_native_Qt3DRender_QFrameGraphNode_ptr(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(activeFrameGraph));
    }
    
    private native void setActiveFrameGraph_native_Qt3DRender_QFrameGraphNode_ptr(long __this__nativeId, long activeFrameGraph);
    
    /**
     * <p>See <code><a href="https://doc.qt.io/qt/qt3drender-qrendersettings.html#renderPolicy-prop">Qt3DRender::QRenderSettings::<wbr>setRenderPolicy(Qt3DRender::QRenderSettings::RenderPolicy)</a></code></p>
     */
    @QtPropertyWriter(name="renderPolicy")
    public final void setRenderPolicy(io.qt.qt3d.render.QRenderSettings.@NonNull RenderPolicy renderPolicy){
        setRenderPolicy_native_Qt3DRender_QRenderSettings_RenderPolicy(QtJambi_LibraryUtilities.internal.nativeId(this), renderPolicy.value());
    }
    
    private native void setRenderPolicy_native_Qt3DRender_QRenderSettings_RenderPolicy(long __this__nativeId, int renderPolicy);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     * @hidden
     */
    @NativeAccess
    protected QRenderSettings(QPrivateConstructor p) { super(p); } 
    
    /**
     * Constructor for internal use only.
     * @hidden
     * It is not allowed to call the declarative constructor from inside Java.
     */
    @NativeAccess
    protected QRenderSettings(QDeclarativeConstructor constructor) {
        super((QPrivateConstructor)null);
        initialize_native(this, constructor);
    } 
    
    @QtUninvokable
    private static native void initialize_native(QRenderSettings instance, QDeclarativeConstructor constructor);
    
    
    /**
     * <p>Overloaded constructor for {@link #QRenderSettings(io.qt.qt3d.core.QNode)}
     *  with <code>parent = null</code>.</p>
     */
    public QRenderSettings() {
        this((io.qt.qt3d.core.QNode)null);
    }
    
    /**
     * <p>Kotlin property getter. In Java use {@link #activeFrameGraph()} instead.</p>
     */
    @QtPropertyReader(enabled=false)
    @QtUninvokable
    public final io.qt.qt3d.render.@Nullable QFrameGraphNode getActiveFrameGraph() {
        return activeFrameGraph();
    }
    
    /**
     * <p>Kotlin property getter. In Java use {@link #pickingSettings()} instead.</p>
     */
    @QtPropertyReader(enabled=false)
    @QtUninvokable
    public final io.qt.qt3d.render.@Nullable QPickingSettings getPickingSettings() {
        return pickingSettings();
    }
    
    /**
     * <p>Kotlin property getter. In Java use {@link #renderCapabilities()} instead.</p>
     */
    @QtPropertyReader(enabled=false)
    @QtUninvokable
    public final io.qt.qt3d.render.@Nullable QRenderCapabilities getRenderCapabilities() {
        return renderCapabilities();
    }
    
    /**
     * <p>Kotlin property getter. In Java use {@link #renderPolicy()} instead.</p>
     */
    @QtPropertyReader(enabled=false)
    @QtUninvokable
    public final io.qt.qt3d.render.QRenderSettings.@NonNull RenderPolicy getRenderPolicy() {
        return renderPolicy();
    }
}

==> qtjambi-qt3drender-6.6.2-sources.jar: io/qt/qt3d/render/QRenderSettings.java <==
package io.qt.qt3d.render;

import io.qt.*;


/**
 * <p>Holds settings related to rendering process and host the active FrameGraph</p>
 * <p>Java wrapper for Qt class <code><a href="https://doc.qt.io/qt/qt3drender-qrendersettings.html">Qt3DRender::QRenderSettings</a></code></p>
 */
public class QRenderSettings extends io.qt.qt3d.core.QComponent
{
    static {
        QtJambi_LibraryUtilities.initialize();
    }
    
    
    /**
     * This variable stores the meta-object for the class.
     */
    public static final io.qt.core.@NonNull QMetaObject staticMetaObject = io.qt.core.QMetaObject.forType(QRenderSettings.class);
    
    /**
     * <p>Java wrapper for Qt enum <code><a href="https://doc.qt.io/qt/qt3drender-qrendersettings.html#RenderPolicy-enum">Qt3DRender::QRenderSettings::RenderPolicy</a></code></p>
     */
    public enum RenderPolicy implements QtEnumerator {
        /**
         * <p>Representing <code><a href="https://doc.qt.io/qt/qt3drender-qrendersettings.html#RenderPolicy-enum">Qt3DRender::<wbr/>QRenderSettings::<wbr/>OnDemand</a></code></p>
         */
        OnDemand(0),
        /**
         * <p>Representing <code><a href="https://doc.qt.io/qt/qt3drender-qrendersettings.html#RenderPolicy-enum">Qt3DRender::<wbr/>QRenderSettings::<wbr/>Always</a></code></p>
         */
        Always(1);

        static {
            QtJambi_LibraryUtilities.initialize();
        }

        private RenderPolicy(int value) {
            this.value = value;
        }

        /**
         * {@inheritDoc}
         */
        public int value() {
            return value;
        }

        /**
         * Returns the corresponding enum entry for the given value.
         * @param value
         * @return enum entry
         */
        public static @NonNull RenderPolicy resolve(int value) {
            switch (value) {
            case 0: return OnDemand;
            case 1: return Always;
            default: throw new QNoSuchEnumValueException(value);
            }
        }


        private final int value;
    }
    

    /**
     * <p>See <code><a href="https://doc.qt.io/qt/qt3drender-qrendersettings.html#activeFrameGraph-prop">Qt3DRender::QRenderSettings::<wbr/>activeFrameGraphChanged(Qt3DRender::QFrameGraphNode*)</a></code></p>
     */
    @QtPropertyNotify(name="activeFrameGraph")
    public final @NonNull Signal1<io.qt.qt3d.render.@Nullable QFrameGraphNode> activeFrameGraphChanged = new Signal1<>();

    /**
     * <p>See <code><a href="https://doc.qt.io/qt/qt3drender-qrendersettings.html#renderPolicy-prop">Qt3DRender::QRenderSettings::<wbr/>renderPolicyChanged(Qt3DRender::QRenderSettings::RenderPolicy)</a></code></p>
     */
    @QtPropertyNotify(name="renderPolicy")
    public final @NonNull Signal1<io.qt.qt3d.render.QRenderSettings.@NonNull RenderPolicy> renderPolicyChanged = new Signal1<>();
    
    /**
     * <p>See <code>Qt3DRender::QRenderSettings::<wbr/>QRenderSettings(Qt3DCore::QNode*)</code></p>
     */
    @SuppressWarnings({"exports"})
    public QRenderSettings(io.qt.qt3d.core.@Nullable QNode parent){
        super((QPrivateConstructor)null);
        initialize_native(this, parent);
    }
    
    private native static void initialize_native(QRenderSettings instance, io.qt.qt3d.core.QNode parent);
    
    /**
     * <p>See <code><a href="https://doc.qt.io/qt/qt3drender-qrendersettings.html#activeFrameGraph-prop">Qt3DRender::QRenderSettings::<wbr/>activeFrameGraph()const</a></code></p>
     */
    @QtPropertyReader(name="activeFrameGraph")
    @QtUninvokable
    public final io.qt.qt3d.render.@Nullable QFrameGraphNode activeFrameGraph(){
        return activeFrameGraph_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native io.qt.qt3d.render.QFrameGraphNode activeFrameGraph_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <code><a href="https://doc.qt.io/qt/qt3drender-qrendersettings.html#pickingSettings-prop">Qt3DRender::QRenderSettings::<wbr/>pickingSettings()</a></code></p>
     */
    @QtPropertyReader(name="pickingSettings")
    @QtPropertyConstant
    @QtUninvokable
    public final io.qt.qt3d.render.@Nullable QPickingSettings pickingSettings(){
        return pickingSettings_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native io.qt.qt3d.render.QPickingSettings pickingSettings_native(long __this__nativeId);
    
    /**
     * <p>See <code><a href="https://doc.qt.io/qt/qt3drender-qrendersettings.html#renderCapabilities-prop">Qt3DRender::QRenderSettings::<wbr/>renderCapabilities()</a></code></p>
     */
    @QtPropertyReader(name="renderCapabilities")
    @QtPropertyConstant
    @QtUninvokable
    public final io.qt.qt3d.render.@Nullable QRenderCapabilities renderCapabilities(){
        return renderCapabilities_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native io.qt.qt3d.render.QRenderCapabilities renderCapabilities_native(long __this__nativeId);
    
    /**
     * <p>See <code><a href="https://doc.qt.io/qt/qt3drender-qrendersettings.html#renderPolicy-prop">Qt3DRender::QRenderSettings::<wbr/>renderPolicy()const</a></code></p>
     */
    @QtPropertyReader(name="renderPolicy")
    @QtUninvokable
    public final io.qt.qt3d.render.QRenderSettings.@NonNull RenderPolicy renderPolicy(){
        return io.qt.qt3d.render.QRenderSettings.RenderPolicy.resolve(renderPolicy_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this)));
    }
    
    @QtUninvokable
    private native int renderPolicy_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <code><a href="https://doc.qt.io/qt/qt3drender-qrendersettings.html#activeFrameGraph-prop">Qt3DRender::QRenderSettings::<wbr/>setActiveFrameGraph(Qt3DRender::QFrameGraphNode*)</a></code></p>
     */
    @QtPropertyWriter(name="activeFrameGraph")
    public final void setActiveFrameGraph(io.qt.qt3d.render.@Nullable QFrameGraphNode activeFrameGraph){
        setActiveFrameGraph_native_Qt3DRender_QFrameGraphNode_ptr(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(activeFrameGraph));
    }
    
    private native void setActiveFrameGraph_native_Qt3DRender_QFrameGraphNode_ptr(long __this__nativeId, long activeFrameGraph);
    
    /**
     * <p>See <code><a href="https://doc.qt.io/qt/qt3drender-qrendersettings.html#renderPolicy-prop">Qt3DRender::QRenderSettings::<wbr/>setRenderPolicy(Qt3DRender::QRenderSettings::RenderPolicy)</a></code></p>
     */
    @QtPropertyWriter(name="renderPolicy")
    public final void setRenderPolicy(io.qt.qt3d.render.QRenderSettings.@NonNull RenderPolicy renderPolicy){
        setRenderPolicy_native_Qt3DRender_QRenderSettings_RenderPolicy(QtJambi_LibraryUtilities.internal.nativeId(this), renderPolicy.value());
    }
    
    private native void setRenderPolicy_native_Qt3DRender_QRenderSettings_RenderPolicy(long __this__nativeId, int renderPolicy);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     * @hidden
     */
    @NativeAccess
    protected QRenderSettings(QPrivateConstructor p) { super(p); } 
    
    /**
     * Constructor for internal use only.
     * It is not allowed to call the declarative constructor from inside Java.
     * @hidden
     */
    @NativeAccess
    protected QRenderSettings(QDeclarativeConstructor constructor) {
        super((QPrivateConstructor)null);
        initialize_native(this, constructor);
    } 
    
    @QtUninvokable
    private static native void initialize_native(QRenderSettings instance, QDeclarativeConstructor constructor);
    
    
    /**
     * <p>Overloaded constructor for {@link #QRenderSettings(io.qt.qt3d.core.QNode)}
     *  with <code>parent = null</code>.</p>
     */
    public QRenderSettings() {
        this((io.qt.qt3d.core.QNode)null);
    }
    
    /**
     * @hidden
     * <p>Kotlin property getter. In Java use {@link #activeFrameGraph()} instead.</p>
     */
    @QtPropertyReader(enabled=false)
    @QtUninvokable
    public final io.qt.qt3d.render.@Nullable QFrameGraphNode getActiveFrameGraph() {
        return activeFrameGraph();
    }
    
    /**
     * @hidden
     * <p>Kotlin property getter. In Java use {@link #pickingSettings()} instead.</p>
     */
    @QtPropertyReader(enabled=false)
    @QtUninvokable
    public final io.qt.qt3d.render.@Nullable QPickingSettings getPickingSettings() {
        return pickingSettings();
    }
    
    /**
     * @hidden
     * <p>Kotlin property getter. In Java use {@link #renderCapabilities()} instead.</p>
     */
    @QtPropertyReader(enabled=false)
    @QtUninvokable
    public final io.qt.qt3d.render.@Nullable QRenderCapabilities getRenderCapabilities() {
        return renderCapabilities();
    }
    
    /**
     * @hidden
     * <p>Kotlin property getter. In Java use {@link #renderPolicy()} instead.</p>
     */
    @QtPropertyReader(enabled=false)
    @QtUninvokable
    public final io.qt.qt3d.render.QRenderSettings.@NonNull RenderPolicy getRenderPolicy() {
        return renderPolicy();
    }
}
